@@ -2,6 +2,9 @@ from django.contrib.admin import ModelAdmin, site
 from django.contrib.auth.models import User
 from django.db import models
 
+from admin_extra_urls.api import button
+from admin_extra_urls.mixins import ExtraUrlMixin
+
 
 class SubclassedImageField(models.ImageField):
     pass
@@ -55,14 +58,19 @@ class DemoOneToOne(models.Model):
         app_label = 'demo'
 
 
-class UserDetailModelAdmin(ModelAdmin):
+class UserDetailModelAdmin(ExtraUrlMixin, ModelAdmin):
     list_display = [f.name for f in UserDetail._meta.fields]
 
 
-class DemoModelAdmin(ModelAdmin):
+class DemoModelAdmin(ExtraUrlMixin, ModelAdmin):
     # list_display = ('char', 'integer', 'logic', 'null_logic',)
     list_display = [f.name for f in DemoModel._meta.fields]
 
+    @button()
+    def import_fixture(self, request):
+        from adminactions.helpers import import_fixture as _import_fixture
+        return _import_fixture(self, request)
+
 
 site.register(DemoModel, DemoModelAdmin)
 site.register(UserDetail, UserDetailModelAdmin)
