@@ -1,18 +1,19 @@
 from django.contrib.auth.models import User
-from django.core.urlresolvers import reverse
+from django.test import TestCase
+from django.urls import reverse
 from django_dynamic_fixture import G
 from django_webtest import WebTestMixin
-from django.test import TransactionTestCase
-from tests.models import DemoModel
-from .utils import CheckSignalsMixin, user_grant_permission, SelectRowsMixin
+from utils import CheckSignalsMixin, SelectRowsMixin, user_grant_permission
 
+from demo.models import DemoModel
 
 __all__ = ['MassUpdateTest', ]
 
 
-class MassUpdateTest(SelectRowsMixin, CheckSignalsMixin, WebTestMixin, TransactionTestCase):
+class MassUpdateTest(SelectRowsMixin, CheckSignalsMixin, WebTestMixin, TestCase):
     fixtures = ['adminactions', 'demoproject']
-    urls = 'tests.urls'
+    urls = 'demo.urls'
+    csrf_checks = True
 
     _selected_rows = [0, 1]
 
@@ -20,13 +21,14 @@ class MassUpdateTest(SelectRowsMixin, CheckSignalsMixin, WebTestMixin, Transacti
     sender_model = DemoModel
 
     def setUp(self):
-        super(MassUpdateTest, self).setUp()
-        self._url = reverse('admin:tests_demomodel_changelist')
+        super().setUp()
+        self._url = reverse('admin:demo_demomodel_changelist')
         self.user = G(User, username='user', is_staff=True, is_active=True)
 
     def _run_action(self, steps=2, **kwargs):
         selected_rows = kwargs.pop('selected_rows', self._selected_rows)
-        with user_grant_permission(self.user, ['tests.change_demomodel', 'tests.adminactions_massupdate_demomodel']):
+        with user_grant_permission(self.user, ['demo.change_demomodel',
+                                               'demo.adminactions_massupdate_demomodel']):
             res = self.app.get('/', user='user')
             res = res.click('Demo models')
             if steps >= 1:
@@ -46,19 +48,19 @@ class MassUpdateTest(SelectRowsMixin, CheckSignalsMixin, WebTestMixin, Transacti
         return res
 
     def test_no_permission(self):
-        with user_grant_permission(self.user, ['tests.change_demomodel']):
+        with user_grant_permission(self.user, ['demo.change_demomodel']):
             res = self.app.get('/', user='user')
             res = res.click('Demo models')
             form = res.forms['changelist-form']
             form['action'] = 'mass_update'
             form.set('_selected_action', True, 0)
             res = form.submit().follow()
-            assert 'Sorry you do not have rights to execute this action' in res.body
+            assert 'Sorry you do not have rights to execute this action' in str(res.body)
 
     def test_validate_on(self):
         self._run_action(**{'_validate': 1})
-        assert DemoModel.objects.filter(char='BBB').exists()
-        assert not DemoModel.objects.filter(char='bbb').exists()
+        assert DemoModel.objects.filter(char='CCCCC').exists()
+        assert not DemoModel.objects.filter(char='ccccc').exists()
 
     def test_validate_off(self):
         self._run_action(**{'_validate': 0})
@@ -66,11 +68,12 @@ class MassUpdateTest(SelectRowsMixin, CheckSignalsMixin, WebTestMixin, Transacti
 
     def test_clean_on(self):
         self._run_action(**{'_clean': 1})
-        assert DemoModel.objects.filter(char='BBB').exists()
-        assert not DemoModel.objects.filter(char='bbb').exists()
+
+        assert DemoModel.objects.filter(char='CCCCC').exists()
+        assert not DemoModel.objects.filter(char='ccccc').exists()
 
     def test_messages(self):
-        with user_grant_permission(self.user, ['tests.change_demomodel', 'tests.adminactions_massupdate_demomodel']):
+        with user_grant_permission(self.user, ['demo.change_demomodel', 'demo.adminactions_massupdate_demomodel']):
             res = self._run_action(**{'_clean': 1}).follow()
             messages = [m.message for m in list(res.context['messages'])]
             self.assertTrue(messages)
